#!/bin/bash

if grep -q "rockchip" /proc/cpuinfo; then
    echo "deb [trusted=yes] file:/cdrom/embedded/ 10.1 rk-drivers" >> /etc/apt/sources.list
    apt-get update
fi

# UKUI
PKGS=(
    # xserver
    xinit xserver-xorg xserver-xorg-video-all
    x11-xserver-utils xserver-xorg-input-libinput

    # lightdm
    lightdm

    # ukui桌面环境
    xdg-user-dirs
    python3-xdg
    mate-terminal
    dpkg-dev
    ukui-greeter
    ukui-desktop-environment
    ukui-kwin

    # 麒麟主题
    libglib2.0-bin
    ubuntukylin-theme
    plymouth-themes
    qt5-ukui-platformtheme
    ubuntukylin-wallpapers

    # 中文
    language-pack-zh-hans
    fontconfig
    xfonts-utils

    # 使用网络UI，约增加8M空间
    network-manager-gnome
    # UKUI自己的网路工具（任务栏右下角网路图标）
    kylin-nm

    # 音量相关
    ukui-media

    # 电源管理
    ukui-power-manager

    # irqbalance
    irqbalance

    # 支持定时关机
    util-linux
    ethtool

    # 系统监视器
    ukui-system-monitor
    # 便签, 记录功能依赖 libqt5sql5-sqlite
    ukui-notebook libqt5sql5-sqlite
    # onboard 运行 依赖 python3-xdg 模块
    onboard python3-xdg
    # FTP
    filezilla
    # VNC工具
    remmina remmina-plugin-vnc
    # 文本编辑器
    pluma

    # vncserver 需要
    xfonts-base

    # 安装Vino
    vino
    # vino中文
    language-pack-gnome-zh-hans-base

    # 2023年4月16日17:50:17 跟ukui主题资源有冲突，暂时先不安装
    # 2023年4月17日17:07:12 锁屏，需要放在主题安装后再安装。否则可能会和主题资源有冲突。
    ukui-screensaver

    # 默认安装的字体
    cesi-fonts-default
    fonts-noto fonts-noto-cjk fonts-noto-core fonts-liberation fonts-freefont-ttf fonts-urw-base35
    fonts-dejavu

    # Bug: 173047, 173893
    ubuntukylin-default-settings

    # Bug: 173445
    kylin-user-guide
    xdg-utils

    # Bug: 173653
    kylin-fonts-bo-cn
    kylin-language-pack-bo-cn
    kylin-language-pack-bo-cn-base

    # Bug: 174090
    system-config-printer

    # Bug: 174380
    libkysset kylin-xinput-calibrator

    # 定制开关机
    time-shutdown

    cups

    # Bug: 181418
    xinput

    # 解决蓝牙功能异常
    pulseaudio-module-bluetooth

    # audio
    alsa-utils
    alsa-base
    linux-sound-base
    pulseaudio
    pavucontrol

    # 185267 【文件管理器】删除U盘内文件时弹出按钮内容显示英文
    # 185434 【文件管理器】取消U盘内文件传输时显示英文
    qttranslations5-l10n

    # riscv未被依赖的，需要显示安装
    xfsprogs
    
    # notify-send
    libnotify-bin

    # 解决用户隐私按钮问题
    kylin-daq

    # 蓝牙相关
    ukui-bluetooth

    # 窗口/工作区切换
    ukui-window-switch
)
install_pkgs "${PKGS[@]}"

# 平台相关 Start

CURRENT_ARCH="$(dpkg --print-architecture)"
# riscv64 不安装的包
if [ "${CURRENT_ARCH}" != "riscv64" ]; then
    PKGS=(
        # 右键菜单 打开终端
        peony-open-terminal

        # 触控板
        ukui-touch-settings-plugin

        kylin-fonts

        # riscv 上 选择文泉驿字体, pluma等应用乱码
        xfonts-wqy
    )
    install_pkgs "${PKGS[@]}"
fi

# fcitx5-chinese-addons 输入法
PKGS=(
    fcitx5
    libfcitx5core7
    libfcitx5utils2
    fcitx5-pinyin
    fcitx5-chinese-addons-data
    fcitx5-chinese-addons
    fcitx5-frontend-gtk3
    fcitx5-frontend-gtk2
    fcitx5-frontend-qt5
    libdouble-conversion3
    fcitx5-config-qt
    libimepinyin0
    libimecore0
    libime-data-language-model
    libime-bin
    libimetable0
    libopencc-data
    libopencc1.1
    opencc
    libxcb-imdkit1
    kylin-virtual-keyboard
    fcitx5-gb18030
    im-config
)
install_pkgs "${PKGS[@]}"

# 平台相关 End

# 平台相关：显卡驱动
if grep -q "rockchip" /proc/cpuinfo ; then
    install_pkgs kylin-enable-bluetooth
    install_pkgs libdrm-cursor

    # 不同CPU主板，安装指定的显卡驱动
    if grep -q "3568" /proc/cpuinfo ; then
        install_pkgs libmali-bifrost-g52-g2p0-x11
    elif grep -q "3566" /proc/cpuinfo ; then
        install_pkgs libmali-bifrost-g52-g2p0-x11
    elif grep -q "3399" /proc/cpuinfo ; then
        install_pkgs libmali-midgard-t86x-r18p0
    elif grep -q "3588" /proc/cpuinfo ; then
        install_pkgs libmali-valhall-g610-g6p0-x11-wayland-gbm
        install_pkgs firefly-rk3588npu-driver
    else
        :
    fi
elif grep -q "Phytium,.*2000" /proc/cpuinfo ; then
    if [ -d "/sys/firmware/efi/efivars" ] ; then
        # 景嘉微显卡
        install_pkgs mwv206-dev
        install_pkgs mwv207-dev
    fi
elif grep -q -E "6640MA|6640A|U6[78]80A" /proc/cpuinfo ; then
    # 兆芯集显驱动
    install_pkgs zhaoxin-linux-graphics-driver-dri
    :
else
    :
fi

# 激活
dpkg -P libkylin-activation
apt-get install -y libmosquitto1 libkylin-activation
# apt-get install -y -q --reinstall --download-only kylin-activation
(
    mkdir -p /opt/activation/
    cd /opt/activation/
    apt-get download kylin-activation
    dpkg -i kylin-activation_*.deb
)
rm -rf /opt/activation

LAST_INSTALL_PKGS=(
    # ukui-lite默认配置文件
    lite-ukui-config
)
install_pkgs "${LAST_INSTALL_PKGS[@]}"

