#!/bin/bash

cat >>/etc/apt/sources.list <<EOF
# security-4j
deb [trusted=yes] file:/cdrom/embedded/ 10.1 security
EOF
cat >/etc/apt/preferences.d/kylin.pref <<EOF
Package: *
Pin: release c=security
Pin-Priority: 1000
EOF
apt-get update

PKGS=(
    # 安全测试工具
    postfix
    tripwire

    newrole
    swatch
    bc
    quota
    stress
    cgroup-tools
    python
    python3
    tcpdump
    gcc
    vlock
    wget
    setools
    chpolicy
    checkpolicy
    gawk
    m4
    policycoreutils-dev
    policycoreutils-python-utils
    dbus
    elinks
    acl
    yhkylin-backup-tools

    away
    xtrlock

    # 安全包
    selinux-policy-targeted
    selinux-policy-common
    selinux-policy-ukmcs
    selinux-policy-dev
    selinux-policy-doc
    selinux-policy-ukmls
    kycryptor
    libsecurity1
    # libsecurity-dev
    libsecurity-conf
    libsecurity1-scripts
    # libsecurity-conf-dev
    openpts

    kic-utils
    kic-tools
    vsftpd
    vsftpd-dbg
    libbox1
    box-utils
    ftp
    set-se-context
    trust-user
    tpm2-tools
    tpm2-fapi
    trousers
    tpm2-xml
    tpm2-sm3-pcr10
    libxtables12
    libip4tc2
    iptables
    libip6tc2
    kysec-sync-daemon
    libkysecwhlist
    libkysec-adv
    libkysec-extend
    sqlcipher
    libkysec
    libkysec-core
    libpam-kysec
    kysec-daemon
    kysec-utils
    kyseclog-daemon
    sysmonitor
    kytrust-bima

    openssh-sftp-server
    openssh-client
    openssh-server
    ssh
    libpam-pwquality
    libpwquality1
    libpwquality-common
    security-switch
    pluma
    kysec-auth

    # 指纹认证

    libqt5sql5-sqlite

    # audit相关
    auditd
    python3-audit

    # 安全设置
    security-set
)

if [ -d "/sys/firmware/efi/efivars" ] ; then
    # 安全包之前安装 grub2-common
    # install_force_confnew_pkgs "grub2-common"
    echo "do nothings"
else
    if grep -q "Loongson" /proc/cpuinfo ; then
        dpkg -P grub2-common grub-efi-loongarch64 grub-efi-loongarch64-bin grub-common
    fi
fi
install_downgrades_pkgs "${PKGS[@]}"

# 安装安全相关软件包
# 平台相关
# amd64 和 arm64安装如下包，龙芯其他架构不安装
CURRENT_ARCH="$(dpkg --print-architecture)"
if [ "${CURRENT_ARCH}" == "arm64" ]; then
    PKGS=(
        amtu
        pam-finger
    )
    install_downgrades_pkgs "${PKGS[@]}"
fi

if [ "${CURRENT_ARCH}" == "amd64" ]; then
    PKGS=(
        amtu
    )
    install_downgrades_pkgs "${PKGS[@]}"
fi

# for 晶晶
# 只有riscv架构安装
CURRENT_ARCH="$(dpkg --print-architecture)"
if [ "${CURRENT_ARCH}" == "riscv64" ]; then
    PKGS=(
        libsemanage1
        libsemanage-common
        python3-semanage
        # ruby-semanage
        semanage-utils
    )
    install_downgrades_pkgs "${PKGS[@]}"
fi

# 更新 grub
if [ -d "/sys/firmware/efi/efivars" ] ; then
    update-grub
fi